rakam_client is an package used for communicating with a rakam server.
If you don't know what rakam is you can check it out here: rakam.io

This package is experimental and have very limited functionality that I've needed in my projects. Additional functionality will be added in time. Hence, use it with caution.
